@@ -3,13 +3,13 @@ package Net::DNS::Parameters;
 ################################################
 ##
 ##	Domain Name System (DNS) Parameters
-##	(last updated 2023-03-29)
+##	(last updated 2024-07-22)
 ##
 ################################################
 
 use strict;
 use warnings;
-our $VERSION = (qw$Id: Parameters.pm 1910 2023-03-30 19:16:30Z willem $)[2];
+our $VERSION = (qw$Id: Parameters.pm 1982 2024-07-23 16:16:53Z willem $)[2];
 
 use integer;
 use Carp;
@@ -112,8 +112,8 @@ my @typebyname = (
 	OPENPGPKEY => 61,					# RFC7929
 	CSYNC	   => 62,					# RFC7477
 	ZONEMD	   => 63,					# RFC8976
-	SVCB	   => 64,					# RFC-ietf-dnsop-svcb-https-10
-	HTTPS	   => 65,					# RFC-ietf-dnsop-svcb-https-10
+	SVCB	   => 64,					# RFC9460
+	HTTPS	   => 65,					# RFC9460
 	SPF	   => 99,					# RFC7208
 	UINFO	   => 100,					# IANA-Reserved
 	UID	   => 101,					# IANA-Reserved
@@ -125,6 +125,7 @@ my @typebyname = (
 	LP	   => 107,					# RFC6742
 	EUI48	   => 108,					# RFC7043
 	EUI64	   => 109,					# RFC7043
+	NXNAME	   => 128,					# draft-ietf-dnsop-compact-denial-of-existence-04
 	TKEY	   => 249,					# RFC2930
 	TSIG	   => 250,					# RFC8945
 	IXFR	   => 251,					# RFC1995
@@ -137,7 +138,9 @@ my @typebyname = (
 	AVC	   => 258,					#
 	DOA	   => 259,					# draft-durand-doa-over-dns
 	AMTRELAY   => 260,					# RFC8777
-	TA	   => 32768,					# http://cameo.library.cmu.edu/ http://www.watson.org/~weiler/INI1999-19.pdf
+	RESINFO	   => 261,					# RFC9606
+	WALLET	   => 262,					#
+	TA	   => 32768,					# http://www.watson.org/~weiler/INI1999-19.pdf
 	DLV	   => 32769,					# RFC8749 RFC4431
 	);
 our %typebyval = reverse( TYPE0 => 0, @typebyname );
@@ -192,7 +195,7 @@ our %rcodebyname = @rcodebyname;
 # Registry: DNS EDNS0 Option Codes (OPT)
 my @ednsoptionbyname = (
 	LLQ		 => 1,					# RFC8764
-	UL		 => 2,					# http://files.dns-sd.org/draft-sekar-dns-ul.txt
+	'UPDATE-LEASE'	 => 2,					# RFC-ietf-dnssd-update-lease-08
 	NSID		 => 3,					# RFC5001
 	DAU		 => 5,					# RFC6975
 	DHU		 => 6,					# RFC6975
@@ -207,6 +210,7 @@ my @ednsoptionbyname = (
 	'EXTENDED-ERROR' => 15,					# RFC8914
 	'CLIENT-TAG'	 => 16,					# draft-bellis-dnsop-edns-tags
 	'SERVER-TAG'	 => 17,					# draft-bellis-dnsop-edns-tags
+	'REPORT-CHANNEL' => 18,					# RFC9567
 	'UMBRELLA-IDENT' => 20292,				# https://developer.cisco.com/docs/cloud-security/#!integrating-network-devic
 	DEVICEID	 => 26946,				# https://developer.cisco.com/docs/cloud-security/#!network-devices-getting-s
 	);
@@ -283,6 +287,7 @@ my @dnserrorbyval = (
 	27 => 'Unsupported NSEC3 Iterations Value',		# RFC9276
 	28 => 'Unable to conform to policy',			# draft-homburg-dnsop-codcp-00
 	29 => 'Synthesized',					# https://github.com/PowerDNS/pdns/pull/12334
+	30 => 'Invalid Query Type',				# draft-ietf-dnsop-compact-denial-of-existence-04
 	);
 our %dnserrorbyval = @dnserrorbyval;
 
@@ -297,18 +302,18 @@ sub classbyname {
 	return $classbyname{$name} || $classbyname{uc $name} || return do {
 		croak qq[unknown class "$name"] unless $name =~ m/^(CLASS)?(\d+)/i;
 		my $val = 0 + $2;
-		croak qq[classbyname("$name") out of range] if $val > 0xffff;
+		croak qq[classbyname("$name") out of range] if $val > 0x7fff;
 		return $val;
 	}
 }
 
 sub classbyval {
-	my $val = shift;
+	my $arg = shift;
 
-	return $classbyval{$val} || return do {
-		$val += 0;
-		croak qq[classbyval($val) out of range] if $val > 0xffff;
-		return "CLASS$val";
+	return $classbyval{$arg} || return do {
+		my $val = ( $arg += 0 ) & 0x7fff;		# MSB used by mDNS
+		croak qq[classbyval($arg) out of range] if $arg > 0xffff;
+		return $classbyval{$arg} = $classbyval{$val} || "CLASS$val";
 	}
 }
 
